/** Verbosity levels for warnings/errors */
var VerbosityCode;
(function (VerbosityCode) {
  /** we may use for cases when frontend sends some wrong params */
  VerbosityCode[VerbosityCode["FRONTEND_CONFIGURATION_ERROR"] = 0] = "FRONTEND_CONFIGURATION_ERROR";
  /** we may use when something critical happens, when stream can’t be received */
  VerbosityCode[VerbosityCode["ERROR"] = 1] = "ERROR";
  /** when stream works but there are some issues, or user will be disconnected soon */
  VerbosityCode[VerbosityCode["WARNING"] = 2] = "WARNING";
  VerbosityCode[VerbosityCode["DEBUG"] = 3] = "DEBUG";
})(VerbosityCode || (VerbosityCode = {}));

/** Any of these Messages is prefixed with "LL: " to enable filtering them.
 * One could also use the enum to directly check for them and take action.
 */
var LoveLetter;
(function (LoveLetter) {
  // Bypass
  LoveLetter["bypassSuccess"] = "LL: Bypass succeeded, about to connect.";
  LoveLetter["bypassFailed"] = "LL: Bypass failed, something went wrong.";
  LoveLetter["bypassNoStream"] = "LL: Bypass succeeded, no stream available.";
  LoveLetter["bypassError"] = "LL: Bypass error.";
  // Vanilla
  LoveLetter["signallingConnectionEstablished"] = "LL: Signalling connection established.";
  LoveLetter["signallingConnectClient"] = "LL: Start connection to stream signalling.";
  LoveLetter["startInstance"] = "LL: No stream found, let's try start one only for you.";
  LoveLetter["startInstanceWithRId"] = "LL: Directly starting stream - debugging.";
  LoveLetter["searchResource"] = "LL: Searching for resources to start the stream.";
  LoveLetter["foundResource"] = "LL: Found resource to start the stream.";
  LoveLetter["commandedStart"] = "LL: Starting stream.";
  LoveLetter["requestInstance"] = "LL: Connecting to cloud.";
  LoveLetter["searchSession"] = "LL: Let's try to find your session.";
  LoveLetter["searchInstance"] = "LL: Searching for stream.";
  LoveLetter["connectClient"] = "LL: Reserving stream.";
  LoveLetter["awaitConnectClient"] = "LL: Waiting for stream.";
  LoveLetter["ticketRegistered"] = "LL: Ticket registered.";
  LoveLetter["ticketDestroyed"] = "LL: Ticket destroyed.";
  LoveLetter["checkToken"] = "LL: Checking token.";
  // ShareId
  LoveLetter["shareIdError"] = "LL: Share error.";
  LoveLetter["shareIdDoesNotExist"] = "LL: Share unknown.";
  LoveLetter["shareIdExpired"] = "LL: Share expired.";
  LoveLetter["shareIdInactive"] = "LL: Share inactive.";
  LoveLetter["shareIdUsageCapReached"] = "LL: Share inactive, usage cap reached.";
  // Errors
  LoveLetter["authorizationError"] = "LL: Authorization error.";
  LoveLetter["scissors"] = "LL: Don't run with scissors.";
  // Art
  LoveLetter["noProjectIdTableFlip"] = "LL: No projectId? (\u25E0\u203F\u25E0 ) (\u256F\u0CA0_\u0CA0)\u256F\uFE35 \u253B\u2501\u253B";
  LoveLetter["tableFlip"] = "LL: (\u256F\u00B0\u25A1\u00B0\uFF09\u256F\uFE35 \u253B\u2501\u253B";
  LoveLetter["shrug"] = "LL: \u00AF\\_(\u30C4)_/\u00AF";
  LoveLetter["wat"] = "LL: \u0CA0_\u0CA0";
  // Specific destroy states.
  LoveLetter["destroy_projectNotDistributed"] = "LL: The requested project is not distributed.";
  LoveLetter["destroy_projectNotYetDistributed"] = "LL: The project is currently in distribution. Please retry in a few minutes.";
  LoveLetter["destroy_projectHasNeverBeenReleased"] = "LL: Project unavailable. This project has never been released.";
  LoveLetter["destroy_projectHasNeverBeenReleasedYet"] = "LL: Project unavailable. Seems to be available soon.";
  LoveLetter["destroy_projectLastReleaseFailed"] = "LL: Project unavailable. Last release failed.";
  LoveLetter["destroy_instanceTimeout"] = "LL: Project didn't start in time.";
  // Easter Eggs:
  LoveLetter["easterEgg_MayTheForce"] = "LL: May the force be with you. ;)";
  LoveLetter["easterEgg_NotProjectLookingFor"] = "LL: This is not the project you are looking for. ;)";
  LoveLetter["easterEgg_BendingTheSpoon"] = "LL: Bending the spoon. ;)";
  LoveLetter["easterEgg_AdjustFluxCapacitor"] = "LL: Adjusting the flux capacitor. ;)";
  LoveLetter["easterEgg_ExecuteGitForcePush"] = "LL: Executing 'git push --force'. ;)";
  LoveLetter["easterEgg_WaitForDaenerys"] = "LL: Waiting for Daenerys to say all her titles ... ;)";
  LoveLetter["easterEgg_ReleasingTheKraken"] = "LL: Releasing the Kraken. ;)";
  LoveLetter["easterEgg_BadFeeling"] = "LL: Uhh ... I have a bad feeling about that. ;)";
  LoveLetter["easterEgg_TestPixelsForCovid"] = "LL: Testing pixels for covid-19.";
})(LoveLetter || (LoveLetter = {}));
const easterEggs = [LoveLetter.easterEgg_NotProjectLookingFor,
// LoveLetter.easterEgg_TestPixelsForCovid,
LoveLetter.easterEgg_BendingTheSpoon, LoveLetter.easterEgg_AdjustFluxCapacitor, LoveLetter.easterEgg_ExecuteGitForcePush, LoveLetter.easterEgg_WaitForDaenerys, LoveLetter.easterEgg_ReleasingTheKraken, LoveLetter.easterEgg_BadFeeling];
function isMayTheFourth() {
  const today = new Date();
  return today.getMonth() + 1 === 5 && today.getDate() === 4;
}
function LoveLetterEasterEgg() {
  try {
    if (isMayTheFourth()) return LoveLetter.easterEgg_MayTheForce;
    if (Math.random() > 0.01) return undefined;
    const len = easterEggs.length;
    const pick = Math.floor(Math.random() * len);
    return easterEggs[pick];
  } catch (_a) {
    return undefined;
  }
}

export { LoveLetter, LoveLetterEasterEgg, VerbosityCode };
