/**
 * Descriptions and interfaces are copied from:
 * https://w3c.github.io/webrtc-pc/#configuration
 * for more information on these properties, please follow the [link]()
 */
export interface IceServer {
    /** STUN or TURN URI(s) as defined in [RFC7064] and [RFC7065] or other URI types. */
    urls: string[];
    /** If this RTCIceServer object represents a TURN server, and credentialType is "password", then this attribute specifies the username to use with that TURN server. */
    username?: string;
    /** If this RTCIceServer object represents a TURN server, then this attribute specifies the credential to use with that TURN server. */
    credential?: string;
    /** If this RTCIceServer object represents a TURN server, then this attribute specifies how credential should be used when that TURN server requests authorization. */
    credentialType?: "password";
}
export interface PeerConnectionOptions {
    /** An array of objects describing servers available to be used by ICE, such as STUN and TURN servers. */
    iceServers?: Array<IceServer>;
    /** Indicates which candidates the ICE Agent is allowed to use. */
    iceTransportPolicy?: RTCIceTransportPolicy;
    /** Indicates which media-bundling policy to use when gathering ICE candidates. */
    bundlePolicy?: RTCBundlePolicy;
    /** Indicates which rtcp-mux policy to use when gathering ICE candidates. */
    rtcpMuxPolicy?: RTCRtcpMuxPolicy;
    /** A set of certificates that the RTCPeerConnection uses to authenticate. */
    certificates?: Array<RTCCertificate>;
    /** Size of the pre fetched ICE pool as defined in [RFC8829] (section 3.5.4. and section 4.1.1.). default = 0 */
    iceCandidatePoolSize?: number;
    /**
     * According to this [bug](https://forums.unrealengine.com/unreal-engine/feedback-for-epic/1869186-pixel-streaming-not-working-in-chrome-version-89-ue4-will-crash-when-i-access-signallingwebserver),
     * the solution seems to be adding 'offerExtmapAllowMixed' with the value false, to prevent crashing of Chrome & Edge.
     *
     * I'd assume this to be an issue of Epic Games with Unreal Engine PixelStreaming.
     */
    offerExtmapAllowMixed?: boolean;
    sdpSemantics?: string;
}
