import Keycloak from "keycloak-js";
import { SnackbarMessage } from "notistack";
import { PeerConnectionOptions, VerbosityCode } from "./ImportSignallingData";
import type { QueueDialogHandle } from "./FrontendWebrtcCommunication";
export interface ExtraSettings {
    afk?: {
        enabled?: boolean;
        warnTime?: number;
        errorTime?: number;
        actionTime?: number;
    };
    no_auth?: boolean;
    /** Share-Link-Id that can be used to bypass an authorization. Using this Id with a projectId will make the signalling check for that shareId and authorize the project if required. */
    shareId?: string;
    keycloak?: Keycloak;
}
export declare type VideoSettings = {
    audio: boolean;
    video: boolean;
    autoPlay: boolean;
};
export declare type Candidate = {
    sdpMid: string;
    sdpMLineIndex: number;
    candidate: string;
};
export declare type PeerConfig = {
    type: string;
    peerConnectionOptions: PeerConnectionOptions;
};
export declare type SnackbarVariants = "default" | "error" | "success" | "warning" | "info";
export declare type EnqueueSnackbar = (message: SnackbarMessage | string | Event | CloseEvent, { variant, autoHideDuration, disableWindowBlurListener, }: {
    variant: SnackbarVariants;
    autoHideDuration?: number;
    disableWindowBlurListener?: boolean;
}, reconnecting?: boolean) => string | number;
export declare type CloseSnackbar = (key: string | number) => void;
export declare type Snackbar = {
    enqueueSnackbar: EnqueueSnackbar;
    closeSnackbar: CloseSnackbar;
};
export declare type InitCallback = (descriptor: any) => unknown;
export interface OrientationZoom {
    portrait: number;
    landscape: number;
}
export interface Autoplay {
    video: boolean;
    audio: boolean;
}
export declare type ApplicationResponse = (response: string) => unknown;
export interface WebRTCClientProps {
    address: string;
    packageId: string;
    sessionId?: string;
    shareId?: string;
    settings: ExtraSettings;
    loader: (val: boolean, disconnected?: boolean) => void;
    snackbar?: Snackbar;
    videoInitializeCallback?: InitCallback;
    sizeContainer: HTMLElement | string;
    container?: HTMLElement;
    videoRef?: HTMLVideoElement;
    audioRef?: HTMLAudioElement;
    orientationZoom?: OrientationZoom;
    forceVideoToFitContainer?: boolean;
    extmapAllowMixed?: boolean;
    unauthorizedFallback?: () => unknown;
    applicationResponse?: ApplicationResponse;
    touchSupport?: boolean;
    autoplay?: Autoplay;
    playOverlay?: boolean;
    updateQueueData?: QueueDialogHandle["updateQueueData"];
    verbosityLevel?: VerbosityCode;
    sendResolutionOnResize?: boolean;
    sendLetter?: (letter: string) => unknown;
    keycloakUrl?: string;
    clientId?: string;
}
